@@ -136,7 +136,8 @@ class NcmClient:
                     chunks = self.__chunk_param(val)
                     # For each chunk, get the full results list and filter by __in parameter
                     for chunk in chunks:
-                        params.update({key: chunk})
+                        chunkstr = ','.join(map(str, chunk))
+                        params.update({key: chunkstr})
                         url = geturl
                         while url and (len(results) < limit):
                             ncm = self.session.get(url, params=params)
@@ -169,7 +170,7 @@ class NcmClient:
 
         bad_params = {k: v for (k, v) in kwargs.items() if k not in allowed_params}
         if len(bad_params) > 0:
-            raise ValueError("INVALID PARAMETERS: {}".format(bad_params))
+            raise ValueError("Invalid parameters: {}".format(bad_params))
         return params
 
     def __chunk_param(self, param):
@@ -480,7 +481,7 @@ class NcmClient:
         for f in self.get_firmwares(version=firmware_name):
             if f['product'] == '{0}/products/{1}/'.format(self.base_url, str(product_id)):
                 return f
-        raise ValueError("ERROR: Invalid Firmware Version")
+        raise ValueError("Invalid Firmware Version")
         return
 
     def get_firmware_for_productname_by_version(self, product_name, firmware_name):
@@ -830,7 +831,7 @@ class NcmClient:
         for p in self.get_products():
             if p['name'] == product_name:
                 return p
-        raise ValueError("ERROR: Invalid Product Name")
+        raise ValueError("Invalid Product Name")
         return
 
     def reboot_device(self, router_id):
